@@ -39,43 +39,10 @@ typedef struct url_escape_seq {
 /************************************************************************
  * Globals 
  ***********************************************************************/
-static url_escape_seq_t url_escape_seq[] = {
-  { '?', "%3F", 3 },
-  { '\n', "%0D", 3 },
-  { ' ', "+", 1 },
-  { '/', "%2F", 3 },
-  { ';', "%3B", 3 },
-  { '%', "%25", 3 },
-  { '=', "%3D", 3 },
-  { '"', "%22", 3 },
-  { '\'', "%2C", 3 },
-  { '.', "%2E", 3 },
-  { ':', "%3A", 3 },
-  { '@', "%40", 3 },
-  { '\\', "%5C", 3 },
-  { '&', "%26", 3 },
-  { '+', "%2B", 3 },
-};
 
 /************************************************************************
  * Local
  ***********************************************************************/
-/**
- * Get index of url escape sequenze array 
- *
- * @param c IN char for lookup
- *
- * @return index of url escape sequenz array
- */
-static int get_url_escape_index(char c) {
-  int i;
-  for (i = 0; i < sizeof(url_escape_seq)/sizeof(url_escape_seq_t); i++) {
-    if (url_escape_seq[i].c == c) {
-      return i;
-    }
-  }
-  return -1;
-}
 
 /************************************************************************
  * Commands 
@@ -91,15 +58,14 @@ static int get_url_escape_index(char c) {
  */
 apr_status_t block_CODER_URLENC(worker_t *worker, worker_t *parent, apr_pool_t *ptmp) {
   /* do this the old way, becaus argv tokenizer removes all "\" */
-  const char *string;
+  const unsigned char *string;
   const char *var;
-  char *result;
+  unsigned char *result;
   int i;
   int j;
-  int k;
   apr_size_t len;
 
-  string = store_get(worker->params, "1");
+  string = (const unsigned char *)store_get(worker->params, "1");
   var = store_get(worker->params, "2");
 
   if (!string) {
@@ -111,23 +77,28 @@ apr_status_t block_CODER_URLENC(worker_t *worker, worker_t *parent, apr_pool_t *
     return APR_EGENERAL;
   }
 
-  len = strlen(string);
+  len = strlen((const char *)string);
   /* allocate worste case -> every char enc with pattern %XX */
   result = apr_pcalloc(ptmp, 3 * len + 1);
 
   /** do the simple stuff */
   for (j = 0, i = 0; string[i]; i++) {
-    k = get_url_escape_index(string[i]);
-    if (k != -1) {
-      strncpy(&result[j], url_escape_seq[k].esc, url_escape_seq[k].len);
-      j += url_escape_seq[k].len;
+    if ((string[i] >= 'a' && string[i] <= 'z') ||
+        (string[i] >= 'A' && string[i] <= 'Z') ||
+        (string[i] >= '0' && string[i] <= '9') ||
+        string[i] == '-' || string[i] == '_' || string[i] == '~') {
+      result[j++] = string[i];
+    }
+    else if (string[i] == ' ') {
+      result[j++] = '+';
     }
     else {
-      result[j++] = string[i];
+	  strncpy((char *)&result[j], apr_psprintf(ptmp, "%%%2X", string[i]), 3);
+	  j += 3;
     }
   }
 
-  worker_var_set(parent, var, result);
+  worker_var_set(parent, var, (char *)result);
 
   return APR_SUCCESS;
 
@@ -174,13 +145,13 @@ apr_status_t block_CODER_URLDEC(worker_t *worker, worker_t *parent, apr_pool_t *
     else if (string[i] == '%') {
       if (i + 2 < len) {
         c = x2c(&string[i + 1]);
-	i += 2;
+        i += 2;
       }
     }
     else if (string[i] == '\\' && i + 1 < len && string[i + 1] == 'x') {
       if (i + 3 < len) {
         c = x2c(&string[i + 2]);
-	i += 3;
+        i += 3;
       }
     }
     inplace[j] = c;
