@@ -91,6 +91,7 @@ typedef struct global_replacer_s {
 /************************************************************************
  * Globals 
  ***********************************************************************/
+global_t *global = NULL;
 extern module_t modules[];
 
 static void show_commands(apr_pool_t *p, global_t *global); 
@@ -717,12 +718,10 @@ static apr_status_t worker_interpret(worker_t * worker, worker_t *parent,
     char *line;
     apr_pool_t *ptmp;
 
-    apr_pool_create(&ptmp, NULL);
-    worker->file_and_line = e[worker->cmd].key;
+    apr_pool_create_unmanaged_ex(&ptmp, NULL, NULL);
     line = e[worker->cmd].val;
     if (worker_is_block(worker, line, ptmp)) {
       status = command_CALL(NULL, worker, line, ptmp);
-      worker->file_and_line = e[worker->cmd].key;
       status = worker_check_error(parent, status);
     }
     else {
@@ -775,19 +774,8 @@ void worker_finally(worker_t *worker, apr_status_t status) {
   if (alt_status != APR_SUCCESS) {
     status = alt_status;
   }
-
-  if (worker->tmpf) {
-    const char *name;
-
-    /* get file name */
-    if (apr_file_name_get(&name, worker->tmpf) == APR_SUCCESS) {
-      /* close file */
-      apr_file_close(worker->tmpf);
-      worker->tmpf = NULL;
-
-      apr_file_remove(name, worker->pbody);
-    }
-  }
+ 
+  worker_finally_cleanup(worker);
 
   if (status != APR_SUCCESS) {
     set_threads(worker->global, 0);
@@ -847,8 +835,6 @@ static void * APR_THREAD_FUNC worker_thread_client(apr_thread_t * thread, void *
   worker->mythread = thread;
   worker->flags |= FLAGS_CLIENT;
 
-  worker->file_and_line = apr_psprintf(worker->pbody, "%s:-1", worker->filename);
-
   worker->which = get_tot_threads(worker->global);
   inc_threads(worker->global);
   inc_tot_threads(worker->global);
@@ -863,6 +849,7 @@ static void * APR_THREAD_FUNC worker_thread_client(apr_thread_t * thread, void *
 
   worker_flush(worker, worker->pbody);
 
+  --worker->cmd;
   if ((status = worker_test_unused(worker)) != APR_SUCCESS) {
     goto error;
   }
@@ -895,8 +882,6 @@ static void * APR_THREAD_FUNC worker_thread_daemon(apr_thread_t * thread, void *
   inc_tot_threads(worker->global);
   worker->logger = logger_clone(worker->pbody, worker->logger, worker->which);
 
-  worker->file_and_line = apr_psprintf(worker->pbody, "%s:-1", worker->filename);
-
   worker_log(worker, LOG_INFO, "Daemon start ...");
 
   worker_log(worker, LOG_DEBUG, "unlock %s", worker->name);
@@ -1172,13 +1157,12 @@ static apr_status_t global_new(global_t **global, store_t *vars,
                                apr_file_t *err, int logger_flags) {
   appender_t *appender;
   apr_status_t status;
-  apr_pool_t *pmutex;
   apr_thread_mutex_t *mutex;
 
   *global = apr_pcalloc(p, sizeof(global_t));
 
-  apr_pool_create(&pmutex, NULL);
   (*global)->pool = p;
+  apr_pool_create(&(*global)->cleanup_pool, NULL);
   (*global)->config = apr_hash_make(p);
   (*global)->vars = vars;
 
@@ -1241,7 +1225,7 @@ static apr_status_t global_new(global_t **global, store_t *vars,
 
   if ((status = apr_thread_mutex_create(&(*global)->sync_mutex, 
 	                                APR_THREAD_MUTEX_DEFAULT,
-                                        pmutex)) != APR_SUCCESS) {
+                                        p)) != APR_SUCCESS) {
     apr_file_printf(err, "\n"
                "Global creation: could not create sync mutex");
     return status;
@@ -1249,7 +1233,7 @@ static apr_status_t global_new(global_t **global, store_t *vars,
  
   if ((status = apr_thread_mutex_create(&(*global)->mutex, 
 	                                APR_THREAD_MUTEX_DEFAULT,
-                                        pmutex)) != APR_SUCCESS) {
+                                        p)) != APR_SUCCESS) {
     apr_file_printf(err, "\n"
                "Global creation: could not create mutex");
     return status;
@@ -1367,7 +1351,7 @@ static apr_status_t global_END(command_t *self, global_t *global, char *data,
       return status;
     }
 
-    apr_pool_cleanup_register(global->pool, global->cur_worker->name, 
+    apr_pool_cleanup_register(global->cleanup_pool, global->cur_worker->name, 
                               worker_file_cleanup, apr_pool_cleanup_null);
     global->state = GLOBAL_STATE_NONE;
     return APR_SUCCESS;
@@ -2180,7 +2164,7 @@ static apr_status_t interpret_recursiv(apr_file_t *fp, global_t *global) {
 	/* replace all variables for global commands */
 	line = replacer(global->pool, &line[i], replacer_hook, global_replacer);
 
-        apr_pool_create(&ptmp, NULL);
+        apr_pool_create_unmanaged_ex(&ptmp, NULL, NULL);
 	/* lookup function index */
 	i = 0;
 	command = lookup_command(global_commands, line);
@@ -2229,7 +2213,6 @@ static apr_status_t interpret(apr_file_t * fp, store_t * vars, apr_file_t *out,
                               char *additional, int log_thread_no) {
   apr_status_t status;
   int i;
-  global_t *global;
 
   if ((status = global_new(&global, vars, log_mode, p, out, err, log_thread_no)) 
       != APR_SUCCESS) {
@@ -2562,6 +2545,9 @@ exit:
  * own exit func
  */
 static void my_exit() {
+  if (global && global->cleanup_pool) {
+    apr_pool_destroy(global->cleanup_pool);
+  }
   if (success == 0) {
     fprintf(stderr, " FAILED\n");
     fflush(stderr);
@@ -2612,7 +2598,7 @@ int main(int argc, const char *const argv[]) {
   srand(apr_time_now()); 
   
   apr_app_initialize(&argc, &argv, NULL);
-  apr_pool_create(&pool, NULL);
+  apr_pool_create_unmanaged_ex(&pool, NULL, NULL);
 
   /* block broken pipe signal */
 #if !defined(WIN32)
@@ -2819,8 +2805,6 @@ int main(int argc, const char *const argv[]) {
     }
   }
 
-  apr_pool_destroy(pool);
-
   return 0;
 }
 
