@@ -23,6 +23,7 @@ apr_status_t xml_module_init(global_t *global);
 apr_status_t html_module_init(global_t *global);
 apr_status_t js_module_init(global_t *global);
 apr_status_t lua_module_init(global_t *global);
+apr_status_t dso_module_init(global_t *global);
 apr_status_t annotation_module_init(global_t *global);
 apr_status_t charset_module_init(global_t *global);
 apr_status_t perf_module_init(global_t *global);
@@ -45,6 +46,7 @@ module_t modules[] = {
   { html_module_init },
   { js_module_init },
   { lua_module_init },
+  { dso_module_init },
   { annotation_module_init },
   { charset_module_init },
   { perf_module_init },
