@@ -243,7 +243,7 @@ apr_status_t sockreader_read_block(sockreader_t * self, char *block,
   apr_status_t status;
   int i;
   int min_len;
-  int len = *length;
+  apr_size_t len = *length;
 
   status = APR_SUCCESS;
   i = 0;
