@@ -1,8 +1,9 @@
-/* Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. 
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+/**
+ * Copyright 2006 Christian Liesch
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -30,19 +31,13 @@
 #include <config.h>
 #endif
 
-//#include <openssl/ossl_typ.h>
+#include <openssl/ossl_typ.h>
 #include <openssl/ssl.h>
 #include <openssl/rand.h>
 #include <openssl/err.h>
 
-/* on windows the inclusion of windows.h/wincrypt.h causes
- * X509_NAME and a few more to be defined; found no other
- * way than to undef manually before inclusion of engine.h;
- * somehow the same undef in ossl_typ.h is not enough...
- */
-#ifdef OPENSSL_SYS_WIN32
-#undef X509_NAME
-#endif
+/* don't move, needed exactly here on windows */
+#include <module.h>
 
 #ifndef OPENSSL_NO_ENGINE
 #include <openssl/engine.h>
@@ -771,6 +766,21 @@ int debug_verify_callback(int cur_ok, X509_STORE_CTX *ctx) {
   return cur_ok;
 }
 
+/**
+ * verify callback to skip peer cert verification, want always the peer cert
+ * @param cur_ok IN current ok state
+ * @param ctx IN X509 store context
+ */
+int skip_verify_callback(int cur_ok, X509_STORE_CTX *ctx) {
+  X509 *err_cert = X509_STORE_CTX_get_current_cert(ctx);
+  if (!err_cert) {
+    return 0;
+  }
+  else {
+    return 1;
+  }
+}
+
 #endif
 
 #endif
