@@ -597,7 +597,7 @@ static void ssl_message_trace(int write_p, int version, int content_type, const
 #endif
   }
 
-  entry = apr_psprintf(config->msg_pool, "%s: %s%s%s", str_version, 
+  entry = apr_psprintf(config->msg_pool, "%c%s: %s%s%s", dir, str_version, 
                        str_content_type, str_details1, str_details2);
   apr_table_addn(config->msgs, apr_psprintf(config->msg_pool, "TRUE"), entry);
   worker_log_buf(worker, LOG_INFO, dir, entry, strlen(entry));
@@ -1696,6 +1696,10 @@ static apr_status_t ssl_worker_clone(worker_t *worker, worker_t *clone) {
     ssl_wconf_t *clone_config = ssl_get_worker_config(clone);
     /* copy workers content to clone */
     memcpy(clone_config, config, sizeof(*clone_config)); 
+    clone_config->cert_pool = NULL;
+    clone_config->certfile = NULL;
+    clone_config->keyfile = NULL;
+    clone_config->cafile = NULL;
     clone_config->ssl_ctx = NULL;
     return worker_ssl_ctx(clone, config->certfile, config->keyfile, config->cafile, 0);
   }
