@@ -109,7 +109,6 @@ struct worker_s {
   apr_file_t *err;
   /* filename of current script part */
   const char *filename;
-  apr_file_t *tmpf;
 #define FLAGS_NONE           0x00000000
 #define FLAGS_PIPE           0x00000001
 #define FLAGS_CHUNKED        0x00000002
@@ -126,7 +125,6 @@ struct worker_s {
 #define FLAGS_SKIP_FLUSH     0x00002000
 #define FLAGS_LOADED_BLOCK   0x00004000
   int flags;
-  apr_proc_t proc;
   int cmd;
   int cmd_from;
   int cmd_to;
@@ -134,7 +132,6 @@ struct worker_s {
   int group;
   char *name;
   char *additional;
-  char *file_and_line;
   const char *short_desc;
   const char *desc;
   int chunksize;
@@ -155,7 +152,6 @@ struct worker_s {
   apr_table_t *headers_filter;
   apr_table_t *headers_add;
   apr_table_t *headers;
-  apr_table_t *tmp_table;
   apr_hash_t *modules;
   apr_hash_t *blocks;
   apr_hash_t *sockets;
@@ -168,6 +164,7 @@ struct worker_s {
 
 struct global_s {
   apr_pool_t *pool;
+  apr_pool_t *cleanup_pool;
   apr_hash_t *config;
   int flags;
   const char *path;
@@ -426,7 +423,8 @@ apr_status_t worker_expect(worker_t * self, apr_table_t * regexs,
                            const char *data, apr_size_t len); 
 apr_status_t worker_assert(worker_t * self, apr_status_t status); 
 apr_status_t worker_check_error(worker_t *self, apr_status_t status); 
-const char * worker_resolve_var(worker_t *worker, const char *name, apr_pool_t *ptmp); 
+const char * worker_resolve_var(worker_t *worker, const char *name, 
+                                apr_pool_t *ptmp); 
 char * worker_replace_vars(worker_t * worker, char *line, int *unresolved,
                            apr_pool_t *ptmp); 
 apr_status_t worker_flush(worker_t * self, apr_pool_t *ptmp);
@@ -442,6 +440,9 @@ apr_status_t worker_add_line(worker_t * self, const char *file_and_line,
 apr_status_t worker_socket_send(worker_t *self, char *buf, 
                                 apr_size_t len); 
 apr_status_t worker_to_file(worker_t * self);
-const char *worker_get_value_from_param(worker_t *worker, const char *param, apr_pool_t *ptmp); 
+const char *worker_get_value_from_param(worker_t *worker, const char *param, 
+                                        apr_pool_t *ptmp); 
+void worker_finally_cleanup(worker_t *worker);
+const char *worker_get_file_and_line(worker_t *worker); 
 
 #endif
