@@ -1,5 +1,23 @@
 #!/bin/bash
 
+BITS=`getconf LONG_BIT`
+OS=linux
+if [ `uname -o 2>/dev/null` ]; then
+  if [ `uname -o` == "GNU/Linux" ]; then
+    OS=linux
+  elif [ `uname -o` == "Cygwin" ]; then
+    OS=win  # cygwin
+    BITS=32 # httest win is 32 bit
+  fi
+elif [ `uname -s` == "Darwin" ]; then
+  OS=mac
+elif [ `uname -s` == "SunOS" ]; then
+  OS=solaris
+fi
+export BITS
+export OS
+printf "($OS $BITS) "
+
 function run_all {
   list=$1
   count=$2
@@ -32,5 +50,8 @@ function run_all {
 
   if [ $errors -ne 0 ]; then
     printf "\e[1;31m$errors Errors found\e[0m\n"
+	if [ "$OS" == "win" ]; then
+	  exit $errors
+	fi
   fi
 }
